@@ -5,6 +5,6 @@ has_more_pages
 from
 to
 data {{
-    {idField}
+    {dataFields}
 }}
 """
